(get-started)=
# 🚀 Get Started

:::{toctree}
:maxdepth: 1
:hidden:
install.md
testset_generation.md
evaluation.md
monitoring.md
:::

Welcome to the Ragas tutorials! If you're new to Ragas, the Get Started guides will walk you through the fundamentals of working with Ragas. These tutorials assume basic knowledge of Python and Retrieval Augmented Generation (RAG) pipelines. 

Before you proceed further, ensure that you have [Ragas installed](./install.md)!

:::{note}
The tutorials only provide an overview of what you can accomplish with Ragas and the basic skills needed to utilize it effectively. For an in-depth explanation of the core concepts behind Ragas, check out the [Core Concepts](../concepts/index.md) page. You can also explore the [How-to Guides](../howtos/index.md) for specific applications of Ragas.
:::

If you have any questions about Ragas, feel free to join and ask in the `#questions` channel in our Discord community.

Let's get started!

:::{card} Generate a Synthetic Testset
:link: get-started-testset-generation
:link-type: ref

Learn how to generate `Question/Context/Ground_Truth` triplets to get started.
:::

:::{card} Evaluate Using Your Testset
:link: get-started-evaluation
:link-type: ref

Find out how to evaluate your RAG pipeline using your test set (your own dataset or synthetic).
:::

:::{card} Monitor Your RAG in Production
:link: get-started-monitoring
:link-type: ref

Discover how to monitor the performance and quality of your RAG application in production.
:::
